@@ -1,4 +1,6 @@
+import os
 from typing import Text
+from uuid import UUID
 
 
 def getOrElse(default, value):
@@ -7,19 +9,22 @@ def getOrElse(default, value):
     else:
         return default
 
-blue='blue'
-closed='closed'
-create='create'
-doing='doing'
-green='green'
-made='made'
-new='new'
-new_man='new_man'
-red='red'
-restarted='restarted'
-started='started'
-transferred='transferred'
-update='update'
+
+blue = 'blue'
+closed = 'closed'
+create = 'create'
+deleted = 'deleted'
+doing = 'doing'
+green = 'green'
+made = 'made'
+new = 'new'
+new_man = 'new_man'
+red = 'red'
+restarted = 'restarted'
+started = 'started'
+transferred = 'transferred'
+update = 'update'
+
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
     if blink:
@@ -31,3 +36,7 @@ def blinkString(text, blink=True, color="black", bold=False) -> Text:
         return f'<b>{res}</b>'
     else:
         return res
+
+
+def uuid4():
+    return str(UUID(bytes=os.urandom(16), version=4)).upper().replace('-', '_')
