@@ -455,7 +455,11 @@ class CommonQuerySet(QuerySet):
         host = kwargs.get('host')
         queryResult = self._get_range_rows(*args, **kwargs)
 
-        logger.debug(f'\n\n{queryResult.query}\n')
+        try:
+            logger.debug(f'\n\n{queryResult.query}\n')
+        except Exception as ex:
+            logger.warning(ex)
+
         if function:
             res = [function(record=record, user_id=user_id, ws_channel=ws_channel, ws_port=ws_port, host=host, username=username) for record in queryResult]
             return res
