@@ -4,8 +4,7 @@ from itertools import chain
 from bitfield import BitHandler, Bit
 from django.db.models import ForeignKey
 
-from isc_common import setAttr, Stack
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common import setAttr
 
 
 def DecimalToStr(value):
@@ -53,6 +52,7 @@ def IntToNumber(s):
 
     return float(s)
 
+
 def ToNumber(s):
     if s == None:
         return 0
@@ -68,6 +68,7 @@ def ToNumber(s):
     else:
         raise Exception(f'{s} unknown type.')
 
+
 def ToDecimal(s):
     if s == None:
         return 0
@@ -121,6 +122,7 @@ def GetPropsInt(value):
     else:
         value
 
+
 def model_2_dict(instance, fields=None, exclude=None):
     """
     Return a dict containing the data in ``instance`` suitable for passing as
@@ -148,6 +150,7 @@ def model_2_dict(instance, fields=None, exclude=None):
             data[f.name] = f.value_from_object(instance)
     return data
 
+
 def compare_2_dict(dict1, dict2):
     if not isinstance(dict1, dict):
         raise Exception(f'dict1 must be dict')
@@ -161,3 +164,24 @@ def compare_2_dict(dict1, dict2):
         if x_values != y_values:
             messages.append(f'{x_values} != {y_values}')
     return messages
+
+
+class Set:
+    def __init__(self, lst):
+        if isinstance(lst, set):
+            self._set = set
+
+        if isinstance(lst, list):
+            self._lst = lst
+
+
+    @property
+    def get_set_sorted_as_original(self):
+        if self._lst != None:
+            return sorted(set(self._lst), key=self._lst.index)
+        elif self._set != None:
+            return list(self._set)
+        else:
+            return []
+
+
